@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_mgg.c,v 1.19 2009/01/09 04:02:35 guru Exp $
+ *	$Id: gmt_mgg.c,v 1.23 2010/03/22 18:55:47 guru Exp $
  *
- *    Copyright (c) 1991-2009 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2010 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -42,7 +42,7 @@ char *gmtmgg_path[10];	/* Max 10 directories for now */
 int n_gmtmgg_paths = 0;	/* Number of these directories */
 char *MGG_SHAREDIR;	/* Copy of GMT_SHAREDIR (for DLL purposes) */
 
-BOOLEAN MGD77_first_1900 = FALSE, MGD77_first_2000 = FALSE;
+GMT_LONG MGD77_first_1900 = FALSE, MGD77_first_2000 = FALSE;
 
 /* GMT function gmtmgg_date computes the date (hr/mi/sec/dd/mm/yy) based
  * on the total time in seconds since the beginning of first_year.
@@ -233,14 +233,14 @@ int gmtmggpath_func (char *leg_path, char *leg)
 	return(1);
 }
 	
-int gmtmgg_decode_MGD77 (char *string, int tflag, struct GMTMGG_REC *record, struct GMTMGG_TIME **gmt)
+int gmtmgg_decode_MGD77 (char *string, int tflag, struct GMTMGG_REC *record, struct GMTMGG_TIME **gmt, int anom_offset)
 {
 	int year, month, day, hour, min, sec, l_mag, l_top, test, bin, zone, l_twt;
 	short int twt;
 	double tz, fmin;
 	char s_tz[5], s_yr[5], s_mo[3], s_dy[3], s_hr[3], s_mi[6], s_lat[8], s_lon[9];
 	char s_faa[5], s_mag[6], s_top[7], s_top_twt[7];
-	BOOLEAN version_Y2K;
+	GMT_LONG version_Y2K;
 
 	version_Y2K = (string[0] == '5');	/* New format that is Y2K compliant */
 
@@ -328,14 +328,23 @@ int gmtmgg_decode_MGD77 (char *string, int tflag, struct GMTMGG_REC *record, str
 		record->gmt[0] = -record->gmt[0];
 		
 	/* Get magnetics */
-	
-	strncpy (s_mag, &string[73], (size_t) 5);	s_mag[5] = 0;
-	l_mag = atoi (s_mag);
-	if (l_mag == 99999 || (s_mag[0] == ' ' && s_mag[1] == ' ' && s_mag[2] == ' ' && s_mag[3] == ' ' && s_mag[4] == ' '))
-		l_mag = GMTMGG_NODATA;
-	else if (string[72] == '-')
-		l_mag = -l_mag;
-	if (l_mag != GMTMGG_NODATA) l_mag = irint (0.1 * l_mag);
+
+	if (anom_offset) {		/* Read total field and subtract 'anom_ofset' */
+		strncpy (s_mag, &string[60], (size_t) 5);	s_mag[5] = 0;
+		l_mag = atoi (s_mag);
+		if (l_mag == 99999 || (s_mag[0] == ' ' && s_mag[1] == ' ' && s_mag[2] == ' ' && s_mag[3] == ' ' && s_mag[4] == ' '))
+			l_mag = GMTMGG_NODATA;
+		if (l_mag != GMTMGG_NODATA) l_mag -= anom_offset;
+	}
+	else {
+		strncpy (s_mag, &string[73], (size_t) 5);	s_mag[5] = 0;
+		l_mag = atoi (s_mag);
+		if (l_mag == 99999 || (s_mag[0] == ' ' && s_mag[1] == ' ' && s_mag[2] == ' ' && s_mag[3] == ' ' && s_mag[4] == ' '))
+			l_mag = GMTMGG_NODATA;
+		else if (string[72] == '-')
+			l_mag = -l_mag;
+		if (l_mag != GMTMGG_NODATA) l_mag = irint (0.1 * l_mag);
+	}
 	record->gmt[1] = l_mag;
 	
 	/* Get Bathymetry */
@@ -377,7 +386,7 @@ int carter_setup (void)
 	and returns 0.  If failure occurs, it returns -1.  */
 
 	FILE *fp = NULL;
-	char buffer [BUFSIZ];
+	char buffer [BUFSIZ], *not_used = NULL;
 	int  i;
 
 	carter_not_initialized = TRUE;
@@ -390,8 +399,8 @@ int carter_setup (void)
                 return (-1);
         }
 
-	for (i = 0; i < 4; i++) fgets (buffer, BUFSIZ, fp);	/* Skip 4 headers */
-	fgets (buffer, BUFSIZ, fp);
+	for (i = 0; i < 4; i++) not_used = fgets (buffer, BUFSIZ, fp);	/* Skip 4 headers */
+	not_used = fgets (buffer, BUFSIZ, fp);
 
 	if ((i = atoi (buffer)) != N_CARTER_CORRECTIONS) {
 		fprintf (stderr, "carter_setup:  Incorrect correction key (%d), should be %d\n", i, N_CARTER_CORRECTIONS);
@@ -408,8 +417,8 @@ int carter_setup (void)
 
 	/* Read the offset table:  */
 
-	fgets (buffer, BUFSIZ, fp);	/* Skip header */
-	fgets (buffer, BUFSIZ, fp);
+	not_used = fgets (buffer, BUFSIZ, fp);	/* Skip header */
+	not_used = fgets (buffer, BUFSIZ, fp);
 
 	if ((i = atoi (buffer)) != N_CARTER_OFFSETS) {
 		fprintf (stderr, "carter_setup:  Incorrect offset key (%d), should be %d\n", i, N_CARTER_OFFSETS);
@@ -426,8 +435,8 @@ int carter_setup (void)
 
 	/* Read the zone table:  */
 
-	fgets (buffer, BUFSIZ, fp);	/* Skip header */
-	fgets (buffer, BUFSIZ, fp);
+	not_used = fgets (buffer, BUFSIZ, fp);	/* Skip header */
+	not_used = fgets (buffer, BUFSIZ, fp);
 
 	if ((i = atoi (buffer)) != N_CARTER_BINS) {
 		fprintf (stderr, "carter_setup:  Incorrect zone key (%d), should be %d\n", i, N_CARTER_BINS);
