@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegy.c,v 1.28 2009/01/09 04:02:35 guru Exp $
+ *	$Id: pssegy.c,v 1.30 2009/08/28 12:08:31 remko Exp $
  *
  *    Copyright (c) 1999-2009 by T. Henstock
  *    See README file for copying and redistribution conditions.
@@ -22,6 +22,9 @@
  *
  *               2.1 10/4/2001 fix unreduce bug, modify to byte-swap if necessary, make 64-bit safe
  *
+ *                   10/7/2009 fix bug when reading trace locations from arbitrary header locations,
+ *                             8 bytes copied, should be 4 bytes 
+ * 
  * This program is free software and may be copied or redistributed under the terms
  * of the GNU public license.
  */
@@ -68,7 +71,7 @@ int main (int argc, char **argv)
 	float *data;
 	SEGYHEAD *header;
 	char *head;
-	long *head2;
+	int head2;
 	SEGYREEL binhead;
 
 	FILE *fpi = NULL, *fpt = NULL;
@@ -360,19 +363,18 @@ use a few of these*/
 	while ((ix<n_traces) && (header = get_segy_header(fpi))){   /* read traces one by one */
 
 		if (plot_offset){ /* plot traces by offset, cdp, or input order */
-			long offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
+			int32_t offset = ((swap_bytes)? GMT_swab4(header->sourceToRecDist): header->sourceToRecDist);
 			x0 = (double) offset;
 		}
 		else if (plot_cdp){
-			long cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
+			int32_t cdpval = ((swap_bytes)? GMT_swab4(header->cdpEns): header->cdpEns);
 			x0 = (double) cdpval;
 		}
 		else if (byte_x){ /* ugly code - want to get value starting at byte_x of header into a double... */
-		   	long plot_loc;
 			head = (char *) header;
-			head2 = (long *) &(head[byte_x]);
-			plot_loc = ((swap_bytes)? GMT_swab4(*head2): *head2);
-		  	x0 = (double) plot_loc;
+			memcpy(&head2, &head[byte_x], 4); /* edited to fix bug where 8bytes were copied from head.
+												Caused by casting to a long directly from char array*/ 
+			x0 = (double) ((swap_bytes)? GMT_swab4(head2): head2);
 		}
 		else
 			x0 = (1.0 + (double) ix);
