@@ -1,4 +1,4 @@
-/*	$Id: x_over.c,v 1.12 2008/08/14 02:46:38 remko Exp $
+/*	$Id: x_over.c,v 1.15 2010/03/22 18:55:47 guru Exp $
  *
  * X_OVER will compute cross-overs between 2 legs (or internal cross-overs
  * if both legs are the same) and write out time,lat,lon,cross-over values,
@@ -54,8 +54,8 @@
 
 typedef int HANDLE;
 
-BOOLEAN over_lap (float xx[2][2], float yy[2][2]);
-BOOLEAN find_cross (double *xc, double *yc, double *tc, double *dc, float *hc, double *xvalues, GMT_LONG *pt, float xx[2][2], float yy[2][2]);
+GMT_LONG over_lap (float xx[2][2], float yy[2][2]);
+GMT_LONG find_cross (double *xc, double *yc, double *tc, double *dc, float *hc, double *xvalues, GMT_LONG *pt, float xx[2][2], float yy[2][2]);
 
 static char *oformat = "%9.5f %9.5f %10.1f %10.1f %9.2f %9.2f %9.2f %8.1f %8.1f %8.1f %5.1f %5.1f\n";
 static int ttime[MAXPOINTS];		/* time (in seconds) at each point */
@@ -71,7 +71,7 @@ static float lat[MAXPOINTS];		/* latitude for each point */
 static float lon[MAXPOINTS];		/* longitude for each point */
 				/* Min/max coordinates for pieces of the legs */
 static float grid_section[4][MAXSECT+1][MAXBLOCK][2];
-BOOLEAN gmt_flag[3] = {FALSE, FALSE, FALSE};		/* TRUE (for each data type) if it exists */
+GMT_LONG gmt_flag[3] = {FALSE, FALSE, FALSE};		/* TRUE (for each data type) if it exists */
 
 int main (int argc, char *argv[])
 {
@@ -102,13 +102,13 @@ int main (int argc, char *argv[])
   GMT_LONG leg, sct[2], blk[2], sect, ntot = 0;
   GMT_LONG arg, block, mode, i;		/* Misc. counters */
 
-  BOOLEAN shift_lon = FALSE;	/* TRUE if areas cross datumline */
-  BOOLEAN internal = FALSE;	/* TRUE if leg1 = leg2 */
-  BOOLEAN x_flag;		/* TRUE if crossover is found */
-  BOOLEAN error = FALSE;	/* TRUE for invalid arguments */
-  BOOLEAN verbose = FALSE;	/* Work in silence */
-  BOOLEAN ok;			/* misc. booleans */
-  BOOLEAN first = TRUE;		/* Used to print out header before first xover */
+  GMT_LONG shift_lon = FALSE;	/* TRUE if areas cross datumline */
+  GMT_LONG internal = FALSE;	/* TRUE if leg1 = leg2 */
+  GMT_LONG x_flag;		/* TRUE if crossover is found */
+  GMT_LONG error = FALSE;	/* TRUE for invalid arguments */
+  GMT_LONG verbose = FALSE;	/* Work in silence */
+  GMT_LONG ok;			/* misc. booleans */
+  GMT_LONG first = TRUE;		/* Used to print out header before first xover */
 
   double x_cross, y_cross;	/* Coordinates of crossover */
   double t_old = -1.0e38;	/* Time of previous crossover */
@@ -128,6 +128,7 @@ int main (int argc, char *argv[])
   float h_cross[2];			/* Heading at crossover along each leg */
   float d_factor[3];			/* Scale factors if applicable */
   float last_lon;			/* Used to check if we cross Greenwich */
+  size_t not_used = 0;
 
   FILE *fp;				/* File pointer */
 
@@ -263,24 +264,24 @@ int main (int argc, char *argv[])
     last_sect[leg] = (npoints[leg]%n_pts_pr_blk[leg])/n_pts_pr_sect[leg];
     last_pt[leg] = npoints[leg] - last_blk[leg]*n_pts_pr_blk[leg]
     		   - last_sect[leg]*n_pts_pr_sect[leg];
-    fread((void *)(&ttime[offset[leg]]), (size_t)4, (size_t)1, fp);
-    fread((void *)(&latitude), (size_t)4, (size_t)1, fp);
-    fread((void *)(&longitude), (size_t)4, (size_t)1, fp);
+    not_used = fread((void *)(&ttime[offset[leg]]), (size_t)4, (size_t)1, fp);
+    not_used = fread((void *)(&latitude), (size_t)4, (size_t)1, fp);
+    not_used = fread((void *)(&longitude), (size_t)4, (size_t)1, fp);
     lat[offset[leg]] = (float)(latitude *0.000001);
     lon[offset[leg]] = (float)(longitude *0.000001);
     /* Make sure geodetic longitudes are used */
     if (lon[offset[leg]] < 0.) lon[offset[leg]] += 360.0;
-    fread((void *)gmt[offset[leg]], (size_t)2, (size_t)3, fp);
+    not_used = fread((void *)gmt[offset[leg]], (size_t)2, (size_t)3, fp);
 
     last_lon = lon[offset[leg]];
     for (rec_no = offset[leg] + 1; rec_no < (offset[leg] + npoints[leg]); rec_no++) {
-      fread((void *)(&ttime[rec_no]), (size_t)4, (size_t)1, fp);
-      fread((void *)(&latitude), (size_t)4, (size_t)1, fp);
-      fread((void *)(&longitude), (size_t)4, (size_t)1, fp);
+      not_used = fread((void *)(&ttime[rec_no]), (size_t)4, (size_t)1, fp);
+      not_used = fread((void *)(&latitude), (size_t)4, (size_t)1, fp);
+      not_used = fread((void *)(&longitude), (size_t)4, (size_t)1, fp);
       lat[rec_no] = (float)(latitude *0.000001);
       lon[rec_no] = (float)(longitude *0.000001);
       if (lon[rec_no] < 0.) lon[rec_no] += 360.0;
-      fread((void *)gmt[rec_no], (size_t)2, (size_t)3, fp);
+      not_used = fread((void *)gmt[rec_no], (size_t)2, (size_t)3, fp);
       for (i = 0; i < 3; i++)
         if (!gmt_flag[i] && gmt[rec_no][i] != NODATA) gmt_flag[i] = TRUE;
       if (fabs(lon[rec_no] - last_lon) > 180.0 ) shift_lon = TRUE;
@@ -531,11 +532,7 @@ int main (int argc, char *argv[])
 		    ym[1][1] = lat[pnt[1]+1];
 		    if (xm[0][1] > xm[1][1]) SWAP(&xm[0][1],&xm[1][1]);
 		    if (ym[0][1] > ym[1][1]) SWAP(&ym[0][1],&ym[1][1]);
-#ifdef __LP64__
-		    delta = labs(pnt[0] - pnt[1]);
-#else
-		    delta = abs(pnt[0] - pnt[1]);
-#endif
+		    delta = GMT_abs(pnt[0] - pnt[1]);
 		    if (over_lap(xm,ym) && delta > 1) {
 		      /* Here we have found a possible crossover. We interpolate to
 		       * find the crossover values for position and time along each
@@ -577,7 +574,7 @@ int main (int argc, char *argv[])
   exit (EXIT_SUCCESS);
 }
 
-BOOLEAN find_cross (double *xc, double *yc, double *tc, double *dc, float *hc, double *xvalues, GMT_LONG *pt, float xx[2][2], float yy[2][2])
+GMT_LONG find_cross (double *xc, double *yc, double *tc, double *dc, float *hc, double *xvalues, GMT_LONG *pt, float xx[2][2], float yy[2][2])
 {
   double delx[2], dely[2], grad[2], xc0, t_next;
   double delt[2], dx[2][3];
@@ -724,7 +721,7 @@ BOOLEAN find_cross (double *xc, double *yc, double *tc, double *dc, float *hc, d
     return (TRUE);
 }
 
-BOOLEAN over_lap (float xx[2][2], float yy[2][2])		/* Checks if the two areas overlap */
+GMT_LONG over_lap (float xx[2][2], float yy[2][2])		/* Checks if the two areas overlap */
 {
   if (xx[1][0] < xx[0][1] || xx[0][0] > xx[1][1]) return (FALSE);
   if (yy[1][0] < yy[0][1] || yy[0][0] > yy[1][1]) return (FALSE);
